import { EOL } from "os";
const httpMethodList = ["get", "put", "post", "delete", "options", "head", "patch", "trace"];
const uniqParameters = (rawParameters) => {
    const parameterMap = rawParameters.reduce((all, parameter) => {
        return { ...all, [`${parameter.in}:${parameter.name}`]: parameter };
    }, {});
    return Object.values(parameterMap);
};
export const create = (rootSchema) => {
    const paths = rootSchema.paths || {};
    const state = {};
    Object.entries(paths).forEach(([requestUri, pathItem]) => {
        httpMethodList.forEach(httpMethod => {
            const operation = pathItem[httpMethod];
            if (!operation) {
                return;
            }
            if (!operation.operationId) {
                return;
            }
            const parameters = [...(pathItem.parameters || []), ...(operation.parameters || [])];
            state[operation.operationId] = {
                httpMethod,
                requestUri,
                comment: [operation.summary, operation.description].filter(Boolean).join(EOL),
                deprecated: !!operation.deprecated,
                requestBody: operation.requestBody,
                parameters: uniqParameters(parameters),
                responses: operation.responses,
            };
        });
    });
    return state;
};
//# sourceMappingURL=Operation.js.map